@@ -109,8 +109,12 @@ var pt = fileName.lastIndexOf (".");
 if (pt < 0) pt = fileName.length;
 fileName = fileName.substring (0, pt);
 this.moData.put ("nboRoot", fileName);
+if (ext.startsWith (".")) {
 fileName += ext;
-var data = this.vwr.getFileAsString3 (fileName, false, null);
+} else {
+pt = fileName.lastIndexOf ("/");
+fileName = fileName.substring (0, pt + 1) + ext;
+}var data = this.vwr.getFileAsString3 (fileName, false, null);
 JU.Logger.info (data.length + " bytes read from " + fileName);
 var isError = (data.indexOf ("java.io.") >= 0);
 if (data.length == 0 || isError && this.nboType !== "AO") throw  new Exception (" supplemental file " + fileName + " was not found");
@@ -134,13 +138,58 @@ throw e;
 });
 Clazz.defineMethod (c$, "getFile46", 
  function () {
-var data = this.getFileData (".46");
-if (data == null) return;
+this.nNOs = this.nAOs = this.nOrbitals;
+var labelKey = J.adapter.readers.quantum.GenNBOReader.getLabelKey (this.nboType);
+var map = null;
 var readerSave = this.reader;
-this.reader = JU.Rdr.getBR (data);
-this.readData46 ();
+try {
+this.reader = JU.Rdr.getBR (this.getFileData (".46"));
+map = this.readData46 (labelKey);
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+try {
+map = this.readOutputProperties (this.getFileData ("output.properties"));
+} catch (ee) {
+if (Clazz.exceptionOf (ee, Exception)) {
+map =  new java.util.Hashtable ();
+this.setMap (map, "NHO", this.nNOs, false);
+this.setMap (map, "NBO", this.nNOs, false);
+this.setMap (map, "NAO", this.nNOs, false);
+} else {
+throw ee;
+}
+}
+} else {
+throw e;
+}
+}
+this.setMap (map, labelKey, this.nNOs, true);
 this.reader = readerSave;
 });
+Clazz.defineMethod (c$, "readOutputProperties", 
+ function (data) {
+var map =  new java.util.Hashtable ();
+var lines = data.$plit ("\n");
+for (var i = lines.length; --i >= 0; ) {
+var line = lines[i];
+if (line.startsWith ("Natural Atomic Orbitals=")) {
+this.setLabels (map, "NAO", line);
+} else if (line.startsWith ("Natural Hybrid Orbitals=")) {
+this.setLabels (map, "NHO", line);
+} else if (line.startsWith ("Natural Bond Orbitals=")) {
+this.setLabels (map, "NBO", line);
+}}
+return map;
+}, "~S");
+Clazz.defineMethod (c$, "setLabels", 
+ function (map, key, line) {
+var tokens = JU.PT.split (line, ":");
+for (var i = tokens.length; --i >= 0; ) {
+var s = JU.PT.split (tokens[i], ",")[1];
+tokens[i] = (s.indexOf ("%") >= 0 ? s.substring (0, s.indexOf (" ")) : JU.PT.rep (s, " ", ""));
+}
+map.put (key, tokens);
+}, "java.util.Map,~S,~S");
 Clazz.defineMethod (c$, "readData47", 
  function () {
 this.allowNoOrbitals = true;
@@ -329,7 +378,6 @@ this.line = this.rd ();
 for (var j = Clazz.doubleToInt ((n - 1) / 10); --j >= 0; ) this.line += this.rd ().substring (1);
 
 this.line = this.line.trim ();
-System.out.println (this.line);
 if (!this.fillSlater (slater, n, pt, ng)) return false;
 }
 this.rd ();
@@ -337,12 +385,11 @@ this.getAlphasAndExponents ();
 return true;
 }, "~S");
 Clazz.defineMethod (c$, "readData46", 
- function () {
+ function (labelKey) {
 var map =  new java.util.Hashtable ();
 var tokens =  new Array (0);
 this.rd ();
-var nNOs = this.nNOs = this.nAOs = this.nOrbitals;
-var labelKey = J.adapter.readers.quantum.GenNBOReader.getLabelKey (this.nboType);
+var nNOs = this.nNOs;
 while (this.line != null && this.line.length > 0) {
 tokens = JU.PT.getTokens (this.line);
 var type = tokens[0];
@@ -357,13 +404,16 @@ nNOs = this.parseIntStr (count);
 var sb =  new JU.SB ();
 while (this.rd () != null && this.line.length > 4 && " NA NB AO NH".indexOf (this.line.substring (1, 4)) < 0) sb.append (this.line.substring (1));
 
-System.out.println (sb.length ());
 tokens =  new Array (Clazz.doubleToInt (sb.length () / 10));
 for (var i = 0, pt = 0; i < tokens.length; i++, pt += 10) tokens[i] = JU.PT.rep (sb.substring2 (pt, pt + 10), " ", "");
 
 map.put (key, tokens);
 }
-tokens = map.get ((this.betaOnly ? "beta_" : "") + labelKey);
+return map;
+}, "~S");
+Clazz.defineMethod (c$, "setMap", 
+ function (map, labelKey, nNOs, doAll) {
+var tokens = map.get ((this.betaOnly ? "beta_" : "") + labelKey);
 this.moData.put ("nboLabelMap", map);
 if (tokens == null) {
 tokens =  new Array (nNOs);
@@ -371,7 +421,8 @@ for (var i = 0; i < nNOs; i++) tokens[i] = this.nboType + (i + 1);
 
 map.put (labelKey, tokens);
 if (this.isOpenShell) map.put ("beta_" + labelKey, tokens);
-}this.moData.put ("nboLabels", tokens);
+}if (!doAll) return;
+this.moData.put ("nboLabels", tokens);
 this.addBetaSet = (this.isOpenShell && !this.betaOnly && !this.is47File);
 if (this.addBetaSet) this.nOrbitals *= 2;
 for (var i = 0; i < this.nOrbitals; i++) this.setMO ( new java.util.Hashtable ());
@@ -383,7 +434,7 @@ J.adapter.readers.quantum.GenNBOReader.setNboLabels (map.get ("beta_" + labelKey
 }var structures = this.getStructureList ();
 J.adapter.readers.quantum.NBOParser.getStructures46 (map.get ("NBO"), "alpha", structures, this.asc.ac);
 J.adapter.readers.quantum.NBOParser.getStructures46 (map.get ("beta_NBO"), "beta", structures, this.asc.ac);
-});
+}, "java.util.Map,~S,~N,~B");
 c$.getLabelKey = Clazz.defineMethod (c$, "getLabelKey", 
  function (labelKey) {
 if (labelKey.startsWith ("P")) labelKey = labelKey.substring (1);
