@@ -120,7 +120,6 @@ if (JU.Logger.debugging) for (var i = 0; i < this.params.title.length; i++) if (
 }return true;
 }if ("sigma" === propertyName) {
 this.params.cutoff = this.params.sigma = (value).floatValue ();
-this.params.isPositiveOnly = false;
 this.params.cutoffAutomatic = false;
 return true;
 }if ("cutoff" === propertyName) {
@@ -135,6 +134,7 @@ return true;
 }if ("cutoffPositive" === propertyName) {
 this.params.cutoff = (value).floatValue ();
 this.params.isPositiveOnly = true;
+this.params.isCutoffAbsolute = false;
 return true;
 }if ("cap" === propertyName || "slab" === propertyName) {
 if (value != null) this.params.addSlabInfo (value);
@@ -181,7 +181,7 @@ return true;
 this.params.insideOut = true;
 return true;
 }if ("sign" === propertyName) {
-this.params.isCutoffAbsolute = true;
+this.params.isCutoffAbsolute = !this.params.isPositiveOnly;
 this.params.colorBySign = true;
 this.colorPtr = 0;
 return true;
@@ -589,6 +589,10 @@ JU.Logger.error ("Could not create isosurface");
 this.params.cutoff = NaN;
 this.surfaceReader.closeReader ();
 return;
+}if (this.params.probes != null) {
+for (var i = this.params.probeValues.length; --i >= 0; ) {
+this.params.probeValues[i] = this.surfaceReader.getValueAtPoint (this.params.probes[i], false);
+}
 }if (this.params.pocket != null && haveMeshDataServer) this.surfaceReader.selectPocket (!this.params.pocket.booleanValue ());
 if (this.params.minSet > 0) this.surfaceReader.excludeMinimumSet ();
 if (this.params.maxSet > 0) this.surfaceReader.excludeMaximumSet ();
