@@ -85,13 +85,15 @@ return this;
 Clazz_defineMethod (c$, "evaluate", 
 function (mp, op, args, tok) {
 switch (tok) {
+case 134218760:
+return (args.length >= 1 && args[0].tok == 4 ? mp.addXStr ((args.length == 1 ?  new java.util.Date ().toString () : this.vwr.apiPlatform.getDateFormat (JS.SV.sValue (args[1]))) + "\t" + JS.SV.sValue (args[0]).trim ()) : mp.addXInt (((System.currentTimeMillis () - JS.MathExt.t0)) - (args.length == 0 ? 0 : args[0].asInt ())));
 case 134218250:
+return (args.length == 1 && args[0].tok == 2 ? mp.addXInt (Math.abs (args[0].asInt ())) : mp.addXFloat (Math.abs (args[0].asFloat ())));
 case 134218242:
 case 134218245:
-case 134217749:
 case 134218244:
 case 134218246:
-return this.evaluateMath (mp, args, tok);
+return (args.length == 1 && this.evaluateMath (mp, args, tok));
 case 1275069441:
 case 1275068928:
 case 1275068929:
@@ -1512,7 +1514,7 @@ throw e;
 }, "JS.ScriptMathProcessor,~A,~B");
 Clazz_defineMethod (c$, "evaluateMath", 
  function (mp, args, tok) {
-if (tok == 134217749) {
+if (tok == 134218760) {
 if (args.length == 1 && args[0].tok == 4) return mp.addXStr (( new java.util.Date ()) + "\t" + JS.SV.sValue (args[0]));
 return mp.addXInt ((System.currentTimeMillis () & 0x7FFFFFFF) - (args.length == 0 ? 0 : args[0].asInt ()));
 }if (args.length != 1) return false;
@@ -2762,6 +2764,7 @@ if (bs.equals (bsA)) bsB.andNot (bsA);
  else if (bs.equals (bsB)) bsA.andNot (bsB);
 }}return bsB;
 }, "JU.BS,JU.BS,~B,~N,J.atomdata.RadiusData,~B");
+c$.t0 = c$.prototype.t0 = System.currentTimeMillis ();
 });
 })(Clazz
 ,Clazz.getClassName
